@@ -145,7 +145,7 @@ class Renderer(QFrame):
         self.draw_approach_circles = True
         # how many frames for each replay to draw on screen at a time
         self.num_frames_on_screen = 15
-        self.only_embolden_keydowns = False
+        self.only_color_keydowns = False
 
         self.next_frame()
 
@@ -197,9 +197,13 @@ class Renderer(QFrame):
             return
         self.next_frame()
 
-    def next_frame(self):
+    def next_frame(self, stepping_backwards=False):
         """
-        prepares next frame
+        Prepares the next frame.
+
+        If we have just set our current time to be less than what it was the
+        previous time next_frame was called, pass stepping_backwards=True so
+        the correct frame can be chosen when searching the frame list.
         """
         # just update the frame if currently loading
         if self.is_loading:
@@ -214,8 +218,18 @@ class Renderer(QFrame):
             self.pause_signal.emit()
             return
 
+        # This is the solution to the issue of stepping forward/backwards
+        # getting stuck on certain frames - we can fix it for stepping forward
+        # by always preferring the right side when searching our array, but when
+        # stepping backwards we need to prefer the left side instead.
+        side = "left" if stepping_backwards else "right"
         for player in self.players:
-            player.end_pos = np.searchsorted(player.t, current_time, "right") - 1
+            player.end_pos = np.searchsorted(player.t, current_time, side)
+            # for some reason side=right and side=left differ by 1 even when
+            # the array has no duplicates, so only account for that in the
+            # right side case
+            if side == "right":
+                player.end_pos -= 1
             player.start_pos = player.end_pos - self.num_frames_on_screen if player.end_pos >= self.num_frames_on_screen else 0
 
         if self.has_beatmap:
@@ -312,9 +326,9 @@ class Renderer(QFrame):
                 # grey out if we don't have a keypress at the start
                 if not bool(player.k[i]):
                     grey_out = True
-                # grey out if we're only emboldening keydowns and this is not a
+                # grey out if we're only coloring keydowns and this is not a
                 # keydown
-                if self.only_embolden_keydowns and not bool(player.keydowns[i]):
+                if self.only_color_keydowns and not bool(player.keydowns[i]):
                     grey_out = True
             self.draw_line((i - player.start_pos) * alpha_step, player.xy[i],
                     player.xy[i + 1], grey_out=grey_out)
@@ -328,9 +342,9 @@ class Renderer(QFrame):
             highlight = t in self.events
             # grey out only if no keys are held by default
             grey_out = not bool(k)
-            # but override if we're only emboldening keydowns and this is not a
+            # but override if we're only coloring keydowns and this is not a
             # keydown
-            if self.only_embolden_keydowns and not bool(player.keydowns[i]):
+            if self.only_color_keydowns and not bool(player.keydowns[i]):
                 grey_out = True
             self.draw_cross(alpha, xy, grey_out=grey_out, highlight=highlight)
         # reset alpha
@@ -665,8 +679,9 @@ class Renderer(QFrame):
 
     def search_nearest_frame(self, reverse=False):
         """
-        Args:
-            Boolean reverse: chooses the search direction
+        Args
+            Boolean reverse: whether to search backwards or forwards through
+                time
         """
         if not reverse:
             next_frames = []
@@ -676,6 +691,11 @@ class Renderer(QFrame):
                 if pos == len(player.xy):
                     pos -= 1
                 next_frames.append(player.t[pos])
+            # if we're only visualizing a beatmap and there's no replays, and
+            # someone tries to advance or retreat frames, min() / max() will
+            # crash because next_frames is empty, so avoid this.
+            if not next_frames:
+                return
             self.seek_to(min(next_frames))
         else:
             prev_frames = []
@@ -685,15 +705,19 @@ class Renderer(QFrame):
                 if pos == -1:
                     pos += 1
                 prev_frames.append(player.t[pos])
-            self.seek_to(max(prev_frames))
+            if not prev_frames:
+                return
+            self.seek_to(max(prev_frames), seeking_backwards=True)
 
-    def seek_to(self, position):
+    def seek_to(self, position, seeking_backwards=False):
         """
         Seeks to position if the change is bigger than ± 10.
         Also calls next_frame() so the correct frame is displayed.
 
         Args:
             Integer position: position to seek to in ms
+            Boolean seeking_backwards: Whether we're seeking to a time before
+                our current time.
         """
         self.clock.time_counter = position
         # if we want to seek somewhere while we're loading sliders, we store
@@ -701,7 +725,7 @@ class Renderer(QFrame):
         if self.is_loading:
             self.seek_to_when_loaded = position
         if self.paused:
-            self.next_frame()
+            self.next_frame(stepping_backwards=seeking_backwards)
 
     def wheelEvent(self, event):
         # support scrolling both vertically or horizontally, just respect
@@ -737,8 +761,8 @@ class Renderer(QFrame):
         # redraw everything for the new raw view
         self.update()
 
-    def only_embolden_keydowns_changed(self, new_state):
-        self.only_embolden_keydowns = new_state
+    def only_color_keydowns_changed(self, new_state):
+        self.only_color_keydowns = new_state
         self.update()
 
     def hitobjects_changed(self, new_state):
